# Neis API

[![PyPI version](https://badge.fury.io/py/Neis-API.svg)](https://badge.fury.io/py/Neis-API)

Neis_API를 사용하기 위해서는 토큰이 필요합니다.<br/>
토큰은 [나이스 교육정보 개방 포탈](https://open.neis.go.kr/portal/mainPage.do) 에서 신청할 수 있습니다.

## 특징

- 나이스 API에 올라와있는 데이터를 가져오고, 활용할 수 있습니다.

## 설치

```shell
pip install Neis-API
```

## 라이선스

이 프로젝트는 MIT License에 속해 있습니다.

## 도와주신 분

- [hyunwoo6321](https://github.com/hyunwoo6321)
